# -*- coding: utf-8 -*-


from mathics.doc.common_doc import MathicsMainDocumentation

documentation = MathicsMainDocumentation()
